@@ -11,7 +11,7 @@ use B;
 use Scalar::Util ();
 use Encode ();
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 # Constructor and accessor, as we're not using Mojo::Base.
 
@@ -65,13 +65,13 @@ sub decode {
   $self->error(undef);
 
   # Missing input
-  $self->error('Missing or empty input') and return unless $bytes;
+  $self->error('Missing or empty input') and return undef unless $bytes;
 
   # Remove BOM
   $bytes =~ s/^(?:\357\273\277|\377\376\0\0|\0\0\376\377|\376\377|\377\376)//g;
 
   # Wide characters
-  $self->error('Wide character in input') and return
+  $self->error('Wide character in input') and return undef
     unless utf8::downgrade($bytes, 1);
 
   # Detect and decode Unicode
@@ -300,7 +300,8 @@ sub _encode_values {
     return _encode_object($value) if $ref eq 'HASH';
 
     # True or false
-    return $value ? 'true' : 'false' if $ref eq 'JSON::Tiny::_Bool';
+    return $$value ? 'true' : 'false' if $ref eq 'SCALAR';
+    return $value  ? 'true' : 'false' if $ref eq 'JSON::Tiny::_Bool';
 
     # Blessed reference with TO_JSON method
     if (Scalar::Util::blessed $value && (my $sub = $value->can('TO_JSON'))) {
